@@ -1,14 +1,24 @@
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, with_statement
+
 import unittest
 from random import randint
-from .. import t, Session, Window, Pane
+from .. import Session, Window, Pane
 from ..util import tmux
 from .helpers import TmuxTestCase, TEST_SESSION_PREFIX
+from . import t
+
+from .. import log
+import logging
+
+logger = logging.getLogger(__name__)
 
 
-class ServerTestCase(TmuxTestCase):
+class ServerTest(TmuxTestCase):
     def test_has_session(self):
         self.assertTrue(t.has_session(self.TEST_SESSION_NAME))
         self.assertFalse(t.has_session('asdf2314324321'))
+        logging.debug('wat')
 
     def test_has_clients(self):
         pass
